@@ -259,7 +259,7 @@ class DrugTake(EntityType):
 class Drug(EntityType):
     """ Drug attributes """
     identifier = String(required=True, unique=True, indexed=True, maxsize=1024)
-    name = String(required=True, maxsize=2048)
+    name = String(required=True, fulltextindexed=True, maxsize=2048)
     description = RichString(fulltextindexed=True)
     # Ids
     pubchem_id = String(maxsize=64)
@@ -340,7 +340,7 @@ class ScoreDefinition(EntityType):
     """ A score definition """
     name = String(maxsize=256, required=True,  fulltextindexed=True)
     category = String(maxsize=64, fulltextindexed=True)
-    type = String(required=True, indexed=True, vocabulary=('string', 'numerical', 'logical'),)
+    type = String(required=True, indexed=True, vocabulary=('both', 'string', 'numerical', 'logical'),)
     unit = String(maxsize=16, indexed=True)
     possible_values = String(maxsize=256, fulltextindexed=True)
 
